@@ -13,14 +13,14 @@ def test_missing(capfd, missfile):
     subprocess.call(['repack', missfile])
     capfd = capfd.readouterr()
     assert """File(s) not Found Error: These files are missing:
-  14N-1H3__MiSSinG__00200-00300.trans.bz2""" in capfd.out
+  data/14N-1H3__MiSSinG__00200-00300.trans.bz2""" in capfd.out
 
 
 def test_exomol_single(capfd):
-    subprocess.call(['repack', 'exomol_repack_single.cfg'])
+    subprocess.call('repack exomol_repack_single.cfg'.split())
     capfd = capfd.readouterr()
-    assert """Unzipping: '14N-1H3__BYTe__00100-00200.trans.bz2'.
-Reading: '14N-1H3__BYTe__00100-00200.trans.bz2'.
+    assert """Unzipping: 'data/14N-1H3__BYTe__00100-00200.trans.bz2'.
+Reading: 'data/14N-1H3__BYTe__00100-00200.trans.bz2'.
   Flagging lines at  500 K:
   Compression rate:       74.01%,    269,648/ 1,037,545 lines.
   Flagging lines at  700 K:
@@ -36,18 +36,18 @@ Successfully rewriten exomol line-transition info into:
 
 
 def test_exomol_two_files(capfd):
-    subprocess.call(['repack', 'exomol_repack_two_files.cfg'])
+    subprocess.call('repack exomol_repack_two_files.cfg'.split())
     capfd = capfd.readouterr()
-    assert """Unzipping: '14N-1H3__BYTe__00100-00200.trans.bz2'.
-Unzipping: '14N-1H3__BYTe__00200-00300.trans.bz2'.
-Reading: '14N-1H3__BYTe__00100-00200.trans.bz2'.
+    assert """Unzipping: 'data/14N-1H3__BYTe__00100-00200.trans.bz2'.
+Unzipping: 'data/14N-1H3__BYTe__00200-00300.trans.bz2'.
+Reading: 'data/14N-1H3__BYTe__00100-00200.trans.bz2'.
   Flagging lines at  500 K:
   Compression rate:       74.01%,    269,648/ 1,037,545 lines.
   Flagging lines at  700 K:
   Compression rate:       72.35%,    286,925/ 1,037,545 lines.
   Total compression rate: 70.75%,    303,456/ 1,037,545 lines.
 
-Reading: '14N-1H3__BYTe__00200-00300.trans.bz2'.
+Reading: 'data/14N-1H3__BYTe__00200-00300.trans.bz2'.
   Flagging lines at  500 K:
   Compression rate:       83.19%,    178,663/ 1,062,896 lines.
   Flagging lines at  700 K:
@@ -63,12 +63,12 @@ Successfully rewriten exomol line-transition info into:
 
 
 def test_exomol_two_isotopes(capfd):
-    subprocess.call(['repack', 'exomol_repack_two_isotopes.cfg'])
+    subprocess.call('repack exomol_repack_two_isotopes.cfg'.split())
     capfd = capfd.readouterr()
-    assert """Unzipping: '14N-1H3__BYTe__00100-00200.trans.bz2'.
-Unzipping: '15N-1H3__BYTe-15__00100-00200.trans.bz2'.
-Reading: '14N-1H3__BYTe__00100-00200.trans.bz2'.
-Reading: '15N-1H3__BYTe-15__00100-00200.trans.bz2'.
+    assert """Unzipping: 'data/14N-1H3__BYTe__00100-00200.trans.bz2'.
+Unzipping: 'data/15N-1H3__BYTe-15__00100-00200.trans.bz2'.
+Reading: 'data/14N-1H3__BYTe__00100-00200.trans.bz2'.
+Reading: 'data/15N-1H3__BYTe-15__00100-00200.trans.bz2'.
   Flagging lines at  500 K:
   Compression rate:       76.73%,    282,278/ 1,212,878 lines.
   Flagging lines at  700 K:
@@ -84,22 +84,22 @@ Successfully rewriten exomol line-transition info into:
 
 
 def test_exomol_two_files_two_iso(capfd):
-    subprocess.call(['repack', 'exomol_repack_two_two.cfg'])
+    subprocess.call('repack exomol_repack_two_two.cfg'.split())
     capfd = capfd.readouterr()
-    assert """Unzipping: '14N-1H3__BYTe__00100-00200.trans.bz2'.
-Unzipping: '15N-1H3__BYTe-15__00100-00200.trans.bz2'.
-Unzipping: '14N-1H3__BYTe__00200-00300.trans.bz2'.
-Unzipping: '15N-1H3__BYTe-15__00200-00300.trans.bz2'.
-Reading: '14N-1H3__BYTe__00100-00200.trans.bz2'.
-Reading: '15N-1H3__BYTe-15__00100-00200.trans.bz2'.
+    assert """Unzipping: 'data/14N-1H3__BYTe__00100-00200.trans.bz2'.
+Unzipping: 'data/15N-1H3__BYTe-15__00100-00200.trans.bz2'.
+Unzipping: 'data/14N-1H3__BYTe__00200-00300.trans.bz2'.
+Unzipping: 'data/15N-1H3__BYTe-15__00200-00300.trans.bz2'.
+Reading: 'data/14N-1H3__BYTe__00100-00200.trans.bz2'.
+Reading: 'data/15N-1H3__BYTe-15__00100-00200.trans.bz2'.
   Flagging lines at  500 K:
   Compression rate:       76.73%,    282,278/ 1,212,878 lines.
   Flagging lines at  700 K:
   Compression rate:       75.20%,    300,854/ 1,212,878 lines.
   Total compression rate: 73.40%,    322,684/ 1,212,878 lines.
 
-Reading: '14N-1H3__BYTe__00200-00300.trans.bz2'.
-Reading: '15N-1H3__BYTe-15__00200-00300.trans.bz2'.
+Reading: 'data/14N-1H3__BYTe__00200-00300.trans.bz2'.
+Reading: 'data/15N-1H3__BYTe-15__00200-00300.trans.bz2'.
   Flagging lines at  500 K:
   Compression rate:       85.06%,    184,349/ 1,234,214 lines.
   Flagging lines at  700 K:
@@ -116,11 +116,11 @@ Successfully rewriten exomol line-transition info into:
 
 def test_exomol_single_unzip(capfd):
     # Unzip files before repacking:
-    subprocess.call(['bzip2','-dk','14N-1H3__BYTe__00100-00200.trans.bz2'])
-    subprocess.call(['bzip2','-dk','14N-1H3__BYTe.states.bz2'])
-    subprocess.call(['repack', 'exomol_repack_single_unzip.cfg'])
+    subprocess.call(['bzip2','-dk','data/14N-1H3__BYTe__00100-00200.trans.bz2'])
+    subprocess.call('bzip2 -dk data/14N-1H3__BYTe.states.bz2'.split())
+    subprocess.call('repack exomol_repack_single_unzip.cfg'.split())
     capfd = capfd.readouterr()
-    assert """Reading: '14N-1H3__BYTe__00100-00200.trans'.
+    assert """Reading: 'data/14N-1H3__BYTe__00100-00200.trans'.
   Flagging lines at  500 K:
   Compression rate:       74.01%,    269,648/ 1,037,545 lines.
   Flagging lines at  700 K:
@@ -133,15 +133,15 @@ kept a total of 303,456 line transitions out of 1,037,545 lines.
 Successfully rewriten exomol line-transition info into:
   'NH3_exomol_050-100um_500-700K_lbl.dat' and
   'NH3_exomol_050-100um_500-700K_continuum.dat'.""" in capfd.out
-    os.remove('14N-1H3__BYTe__00100-00200.trans')
-    os.remove('14N-1H3__BYTe.states')
+    os.remove('data/14N-1H3__BYTe__00100-00200.trans')
+    os.remove('data/14N-1H3__BYTe.states')
 
 
 def test_exomol_single_chunks(capfd):
-    subprocess.call(['repack', 'exomol_repack_single_chunks.cfg'])
+    subprocess.call('repack exomol_repack_single_chunks.cfg'.split())
     capfd = capfd.readouterr()
-    assert """Unzipping: '14N-1H3__BYTe__00100-00200.trans.bz2'.
-Reading: '14N-1H3__BYTe__00100-00200.trans.bz2'.
+    assert """Unzipping: 'data/14N-1H3__BYTe__00100-00200.trans.bz2'.
+Reading: 'data/14N-1H3__BYTe__00100-00200.trans.bz2'.
   Flagging lines at  500 K (chunk 1/2):
   Compression rate:       70.54%,    152,852/   518,772 lines.
   Flagging lines at  700 K:
